
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

class V1::LearningObjects::AttachmentController < ApplicationController
  before_action :set_objects
  before_action :authenticate_user!, only: [:update, :index]
  before_action :authorize!, only: :destroy
  before_action :authorize_update_attachment!, only: :update

  # GET /learning_objects/:learning_object_id/attachment
  def index
    render json: @attachment
  end

  # DELETE /learning_objects/:learning_object_id/attachments/:id
  def destroy
    return render status: :not_found if @learning_object.nil? || @attachment.nil?

    DeleteBitstreamWorker.perform_async(@attachment.id)
    @attachment.destroy

    render status: :ok
  end

  # PUT /learning_objects/:learning_object_id/attachments/:id
  def update
    return render status: :not_found if @learning_object.nil? || @attachment.nil?
    if @attachment.update(infohash: infohash_params[:infohash])
      render status: :ok
    else
      render status: :unprocessable_entity
    end
  end

  private

  def attachment_params
    params.permit(:learning_object_id, :id)
  end

  def infohash_params
    params.permit(:infohash)
  end

  def set_objects
    @learning_object = LearningObject.find(attachment_params[:learning_object_id])
    if ( attachment_params[:id].blank? )
      @attachment = @learning_object.attachment
    else
      @attachment = LearningObject::Attachment.find(attachment_params[:id])
    end
  end

  def authorize!
    return render status: :unauthorized unless @learning_object.attachments.include? @attachment

    authorize(@learning_object, :destroy?)
  end

  def authorize_update_attachment!
    return render status: :unauthorized unless @learning_object.attachments.include? @attachment

    authorize(@learning_object, :add_infohash?)
  end

end
